import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import ExclamationCircle from './ExclamationCircle'
import theme from './theme'

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary[0]}`
  }
})

const Input = ({ warning, className, ...props }) =>
  <Box position='relative'>
    {warning ? <ExclamationCircle position='absolute' top='50%' marginLeft='-5px' marginTop='-6px' /> : null}
    <Box className={cx(`${styles}`, className)} {...props} />
  </Box>

Input.propTypes = {
  ...Box.propTypes,
  warning: PropTypes.bool
}

Input.defaultProps = {
  theme,
  is: 'input',
  rounded: true,
  width: '100%',
  paddingX: 4,
  paddingY: 2,
  textStyle: 'body1'
}

Input.displayName = 'Input'

export default Input
