import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Box from './Box'
import SearchIcon from './SearchIcon'
import theme from './theme'

const styles = css({
  color: theme.backgrounds.white.textColor,
  boxShadow: `inset 0 0 0 1px ${theme.backgrounds.white.borderColor}`,
  '&:focus, &:active': {
    boxShadow: `inset 0 0 0 1px ${theme.colors.primary[0]}`
  }
})

const SearchInput = ({ className, ...props }) =>
  <Box position='relative'>
    <SearchIcon size='small' position='absolute' top='50%' marginLeft={3} marginTop='-8px' />
    <Box className={cx(`${styles}`, className)} {...props} />
  </Box>

SearchInput.propTypes = {
  ...Box.propTypes
}

SearchInput.defaultProps = {
  theme,
  is: 'input',
  circle: true,
  width: '100%',
  paddingX: 4,
  paddingLeft: 7,
  paddingY: 2,
  textStyle: 'body1'
}

SearchInput.displayName = 'SearchInput'

export default SearchInput
