import React, { PropTypes } from 'react'
import styled, { withTheme } from 'styled-components'
import Pane from './Pane'
import Text from './Text'
import Link from './Link'
import Triangle from './Triangle'
import theme from './theme'

const SidebarLink = styled(({ children, active, theme, ...props }) =>
  <Link is='a' secondary display='flex' alignItems='center' padding={2} marginBottom={1} active={active} rounded {...props}>
    <Text is='span' flexAuto>{children}</Text>
    {active ? <Triangle aim='right' fill={theme.intent.secondary.active.linkColor[0]} /> : null}
  </Link>
)`
  &:hover,
  &.active {
    background-color: ${props => props.theme.rawColors.blue50};
  }
`

SidebarLink.defaultProps = {
  theme
}

const Sidebar = (props) =>
  <Pane white borderRight width='240px' padding {...props} />

Sidebar.propTypes = {
  ...Pane.propTypes
}

Sidebar.defaultProps = {
  theme
}

export {
  Sidebar,
  SidebarLink
}
