import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Text,
  Code,
  Content,
  Button
} from '../components'

const quickBrownFox = 'The quick brown fox jumps over the lazy dog'

export default function contentStory (module) {
  storiesOf('Content', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`# Content

The Content component is used for blocks of content. Implements \`<Box />\`.

Styles semantic elements inside. Think of h1-h6, p, ul, ol etc.

\`\`\`
<Content>
  <h1>Code block example</h1>
</Content>

<Content markdown>
{\`
* Make sure there is no whitespace on the left
* Escape your backticks with a backslash.
\`}
</Content>
\`\`\`

prop | type | description | default
-----|------|-------------|-------
\`markdown\`    | boolean | enables markdown | \`undefined\`
\`indentLists\`   | boolean  | adds left margin to lists | \`true\`
\`maxLineWidth\` | boolean/string  | max-width on paragraphs | \`true\` which is 40em

## Implemented styles

* headings h1-h6, although h4-h6 are the same
* paragraphs
* *emphasis*
* **strong**
* [link](example.com)
* \`code\`
* pre block
* unordered list
* ordered list
* line

### Ordered list example

1. Ordered lists
2. Work too...

### Line example

---

### Code block example

\`\`\`
<Content markdown>
  <h1>Code block example</h1>
</Content>
\`\`\`

### Table example

prop | type | description
-----|------|------------
\`john\`    | boolean | hello
\`doe\`   | string  | align-items


`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with markdown', () => (
      <Pane padding={5} clearfix>
        <Content markdown>
{`
# Content with Markdown

Markdown is supported by [react-remarkable](https://github.com/acdlite/react-remarkable) .

Be aware if you are entering markdown as a string there is no whitespace on the left.
Otherwise the parser will think it is a pre block.
`}
        </Content>
      </Pane>
    ))
}
